'''mcrypt wrapper for Python 2 and 3
Copyright (C) 2010 Michael B. Trausch <mike@trausch.us>
License: GPL v3 as published by the Free Software Foundation

This Python extension module makes it possible to use the mcrypt
library from within Python.  At this point it is best suited for small
encryption/decryption jobs, as it does not support (for example)
block-by-block operation just yet.  This is planned for a future
release.

PLEASE NOTE that the API provided by this module is NOT YET STABLE.
That is, the API MAY CHANGE IN A BACKWARDS INCOMPATIBLE WAY.  This is
in part because this is the first library module that I have written
for Python, and I may not get everything exactly "pythonic" the first
time around.  Furthermore, I want to make sure that the APIs used are
going to be as well-designed and non-intrusive as possible so that
picking this library up and using it in a Python program is something
that feels intuitive to any moderately experienced Python programmer.
So, please use this library for your programs, and contribute feedback
on how it can be made better.  For more information, please read the
README that is distributed with these bindings.

This wrapper attempts to expose functionality in a manner useful for
Python applications.  It does not aim to expose all of the raw
functionality of mcrypt.

Encryption keys are generated from passwords, using the PBKDF2 key
derivation function (using the OpenSSL implementation).  Optionally,
PBKDF1 can be used (for algorithms that use short enough keys) if
compatibility with other software that uses PBKDF1 is desired;
however, PBKDF1 should be considered deprecated and only used if
absolutely necessary.  Furthermore, the PBKDF1 functionality is coded
as part of this extension module.

It is of note that this wrapper does _not_ support some of the truly
advanced functionality of the mcrypt library; for example, it only
uses the compiled-in cipher algorithms and modes.  It does not permit
raw access to most of the attributes used by mcrypt.  Also, if you
provide strings it is assumed that they are UTF-8 strings; if this
assumption is not correct, or this assumption somehow breaks the way
your particular application works, then you should pass bytestrings
directly for things like salts and passwords.

Advanced functionality will be exposed by a 'raw_mcrypt' class in a
future release.'''
from .libmcrypt import *
from .EncryptedWriter import EncryptedWriter
from .EncryptedReader import EncryptedReader
